==> explosive-c4_1.2.orig.tar.gz: explosive-c4/src/explosive-c4_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>MainUI</name>
    <message>
        <source>Two local players</source>
        <translation>Due giocatori locali</translation>
    </message>
    <message>
        <source>Play against computer</source>
        <translation>Gioca contro il computer</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <source>←</source>
        <translation>←</translation>
    </message>
    <message>
        <source>↺</source>
        <translation>↺</translation>
    </message>
    <message>
        <source>explosive-c4</source>
        <translation>explosive-c4</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;
&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;explosive-c4&lt;/span&gt;&lt;/p&gt;
&lt;p&gt;Released under AGPLv3&lt;/p&gt;
&lt;p&gt;Contact: Salvo &apos;LtWorf&apos; Tomaselli &lt;a href=&quot;mailto:tiposchi@tiscali.it&quot;&gt;&amp;lt;tiposchi@tiscali.it&amp;gt;&lt;/a&gt; &lt;/p&gt;
&lt;p&gt;&lt;a href=&quot;https://github.com/ltworf/explosive-c4&quot;&gt;https://github.com/ltworf/explosive-c4&lt;/a&gt;&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;
&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;explosive-c4&lt;/span&gt;&lt;/p&gt;
&lt;p&gt;Rilaciato sotto AGPLv3&lt;/p&gt;
&lt;p&gt;Contatto: Salvo &apos;LtWorf&apos; Tomaselli &lt;a href=&quot;mailto:tiposchi@tiscali.it&quot;&gt;&amp;lt;tiposchi@tiscali.it&amp;gt;&lt;/a&gt; &lt;/p&gt;
&lt;p&gt;&lt;a href=&quot;https://github.com/ltworf/explosive-c4&quot;&gt;https://github.com/ltworf/explosive-c4&lt;/a&gt;&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
</TS>

==> explosive-c4_1.3.orig.tar.gz: explosive-c4/src/explosive-c4_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>MainUI</name>
    <message>
        <source>Two local players</source>
        <translation>Due giocatori locali</translation>
    </message>
    <message>
        <source>Play against computer</source>
        <translation>Gioca contro il computer</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <source>←</source>
        <translation>←</translation>
    </message>
    <message>
        <source>↺</source>
        <translation>↺</translation>
    </message>
    <message>
        <source>explosive-c4</source>
        <translation>explosive-c4</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;
&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;explosive-c4&lt;/span&gt;&lt;/p&gt;
&lt;p&gt;Released under AGPLv3&lt;/p&gt;
&lt;p&gt;Contact: Salvo &apos;LtWorf&apos; Tomaselli &lt;a href=&quot;mailto:tiposchi@tiscali.it&quot;&gt;&amp;lt;tiposchi@tiscali.it&amp;gt;&lt;/a&gt; &lt;/p&gt;
&lt;p&gt;&lt;a href=&quot;https://codeberg.org/ltworf/explosive-c4&quot;&gt;https://codeberg.org/ltworf/explosive-c4&lt;/a&gt;&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;
&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;explosive-c4&lt;/span&gt;&lt;/p&gt;
&lt;p&gt;Rilaciato sotto AGPLv3&lt;/p&gt;
&lt;p&gt;Contatto: Salvo &apos;LtWorf&apos; Tomaselli &lt;a href=&quot;mailto:tiposchi@tiscali.it&quot;&gt;&amp;lt;tiposchi@tiscali.it&amp;gt;&lt;/a&gt; &lt;/p&gt;
&lt;p&gt;&lt;a href=&quot;https://codeberg.org/ltworf/explosive-c4&quot;&gt;https://codeberg.org/ltworf/explosive-c4&lt;/a&gt;&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
</TS>
